@@ -830,6 +830,8 @@ editor_init (GtkhtmlEditor *editor)
 	editor->vbox = g_object_ref_sink (gtk_vbox_new (FALSE, 0));
 	gtk_widget_show (editor->vbox);
 
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+
 	gtkhtml_editor_private_init (editor);
 
 	html = gtkhtml_editor_get_html (editor);
@@ -920,13 +922,16 @@ GtkAction *
 gtkhtml_editor_get_action (GtkhtmlEditor *editor,
                            const gchar *action_name)
 {
+	GtkUIManager *manager;
 	GtkAction *action = NULL;
 	GList *iter;
 
 	g_return_val_if_fail (GTKHTML_IS_EDITOR (editor), NULL);
 	g_return_val_if_fail (action_name != NULL, NULL);
 
-	iter = gtk_ui_manager_get_action_groups (editor->priv->manager);
+	manager = gtkhtml_editor_get_ui_manager (editor);
+	iter = gtk_ui_manager_get_action_groups (manager);
+
 	while (iter != NULL && action == NULL) {
 		GtkActionGroup *action_group = iter->data;
 
@@ -934,7 +939,8 @@ gtkhtml_editor_get_action (GtkhtmlEditor *editor,
 			action_group, action_name);
 		iter = g_list_next (iter);
 	}
-	g_assert (action != NULL);
+
+	g_return_val_if_fail (action != NULL, NULL);
 
 	return action;
 }
@@ -943,12 +949,15 @@ GtkActionGroup *
 gtkhtml_editor_get_action_group (GtkhtmlEditor *editor,
                                  const gchar *group_name)
 {
+	GtkUIManager *manager;
 	GList *iter;
 
 	g_return_val_if_fail (GTKHTML_IS_EDITOR (editor), NULL);
 	g_return_val_if_fail (group_name != NULL, NULL);
 
-	iter = gtk_ui_manager_get_action_groups (editor->priv->manager);
+	manager = gtkhtml_editor_get_ui_manager (editor);
+	iter = gtk_ui_manager_get_action_groups (manager);
+
 	while (iter != NULL) {
 		GtkActionGroup *action_group = iter->data;
 		const gchar *name;
@@ -973,7 +982,7 @@ gtkhtml_editor_get_widget (GtkhtmlEditor *editor,
 	g_return_val_if_fail (widget_name != NULL, NULL);
 
 	widget = glade_xml_get_widget (editor->priv->glade_xml, widget_name);
-	g_assert (widget != NULL);
+	g_return_val_if_fail (widget != NULL, NULL);
 
 	return widget;
 }
@@ -990,7 +999,8 @@ gtkhtml_editor_get_managed_widget (GtkhtmlEditor *editor,
 
 	manager = gtkhtml_editor_get_ui_manager (editor);
 	widget = gtk_ui_manager_get_widget (manager, widget_path);
-	g_assert (widget != NULL);
+
+	g_return_val_if_fail (widget != NULL, NULL);
 
 	return widget;
 }
@@ -1077,25 +1087,29 @@ gtkhtml_editor_set_filename (GtkhtmlEditor *editor,
 gboolean
 gtkhtml_editor_get_html_mode (GtkhtmlEditor *editor)
 {
-	GtkToggleAction *action;
+	GtkRadioAction *action;
+	EditorMode mode;
 
 	g_return_val_if_fail (GTKHTML_IS_EDITOR (editor), FALSE);
 
-	action = GTK_TOGGLE_ACTION (ACTION (HTML_MODE));
+	action = GTK_RADIO_ACTION (ACTION (MODE_HTML));
+	mode = gtk_radio_action_get_current_value (action);
 
-	return gtk_toggle_action_get_active (action);
+	return (mode == EDITOR_MODE_HTML);
 }
 
 void
 gtkhtml_editor_set_html_mode (GtkhtmlEditor *editor,
                               gboolean html_mode)
 {
-	GtkToggleAction *action;
+	GtkRadioAction *action;
+	EditorMode mode;
 
 	g_return_if_fail (GTKHTML_IS_EDITOR (editor));
 
-	action = GTK_TOGGLE_ACTION (ACTION (HTML_MODE));
-	gtk_toggle_action_set_active (action, html_mode);
+	action = GTK_RADIO_ACTION (ACTION (MODE_HTML));
+	mode = html_mode ? EDITOR_MODE_HTML : EDITOR_MODE_TEXT;
+	gtk_radio_action_set_current_value (action, mode);
 
 	g_object_notify (G_OBJECT (editor), "html-mode");
 }
